Execution

Struct Execution 

pub struct Execution<J> { /* private fields */ }
Details of an execution of a job.

Implementations

Source

impl<J> Execution<J>

pub const fn id(&self) -> ExecutionId

Return the ID of the execution.

pub const fn executor_id(&self) -> Option<ExecutorId>

Return the executor ID that executed the job, if any.

pub const fn status(&self) -> ExecutionStatus

Return the status of the execution.

pub const fn created_at(&self) -> SystemTime

Return the timestamp when the execution was created.

pub const fn started_at(&self) -> Option<SystemTime>

Return the timestamp when the execution started.

pub const fn succeeded_at(&self) -> Option<SystemTime>

Return the timestamp when the execution successfully completed.

pub const fn failed_at(&self) -> Option<SystemTime>

Return the timestamp when the execution failed.

pub const fn cancelled_at(&self) -> Option<SystemTime>

Return the timestamp when the execution was cancelled.

pub fn ended_at(&self) -> Option<SystemTime>

Get the end time of the execution, if any.

This is the time when the execution either succeeded, failed, or was cancelled.

pub fn output(&self) -> Result<Option<J::Output>>
where J: JobType,

Parse the output of the execution.

pub fn output_json(&self) -> Option<&str>

Return the raw JSON output of the execution.

pub fn failure_reason(&self) -> Option<&str>

Return the failure reason if the execution failed or was cancelled.